# frozen_string_literal: true

require 'spec_helper'

describe AuthStrategist do
  it 'has a version number' do
    expect(described_class::VERSION).not_to be(nil)
  end

  it 'includes Configuration class' do
    expect(described_class::Configuration).to be_kind_of(Class)
  end

  it 'includes BuildStrategy service object' do
    expect(described_class::BuildStrategy).to be_kind_of(Class)
  end

  it 'includes StrategyInterface module' do
    expect(described_class::StrategyInterface).to be_kind_of(Module)
  end

  it 'includes Authorization module' do
    expect(described_class::Authorization).to be_kind_of(Module)
  end

  it 'has configuration getter' do
    expect(described_class).to respond_to(:configuration)
  end

  it 'responds to .configure' do
    expect(described_class).to respond_to(:configure)
  end

  describe '.configure' do
    context 'called with block' do
      let(:strategies_path) { 'spec/dummy/strategies' }

      it 'sets up configuration (strategies_path)' do
        expect(described_class.configuration.strategies_path).to eq(strategies_path)
      end
    end

    context 'called without block' do
      it 'returns current configuration' do
        expect(described_class.configure).to eq(described_class.configuration)
      end
    end
  end

  describe '.strategies' do
    context 'called without block' do
      it 'returns strategies registry' do
        expect(described_class.strategies).to eq(described_class::Registry)
      end
    end
  end
end
