# frozen_string_literal: true

require 'spec_helper'

describe AuthStrategist::Authorization do
  let(:dummy_controller) { DummyController.new }

  context 'included' do
    it 'adds #authorize! method to base' do
      expect(dummy_controller).to respond_to(:authorize!)
    end

    it 'adds #can? method to base' do
      expect(dummy_controller).to respond_to(:can?)
    end

    describe '#authorize!' do
      context 'when authorization fails' do
        it 'raises an error (AuthStrategist::Errors::Unauthorized)' do
          expect { dummy_controller.authorize!(strategy: :dummy_strategy) }
            .to raise_error(AuthStrategist::Errors::Unauthorized)
        end
      end

      context 'when authorization succeeds' do
        it 'returns nil' do
          expect(dummy_controller.authorize!(strategy: :dummy_strategy, dummy_component: :ok))
            .to be_nil
        end
      end
    end

    describe '#can?' do
      context 'when authorization fails' do
        it 'returns false' do
          expect(dummy_controller.can?(strategy: :dummy_strategy))
            .to eq(false)
        end
      end

      context 'when authorization succeeds' do
        it 'returns nil' do
          expect(dummy_controller.can?(strategy: :dummy_strategy, dummy_component: :ok))
            .to eq(true)
        end
      end
    end
  end
end
