# frozen_string_literal: true

require 'spec_helper'

describe AuthStrategist::BuildStrategy do
  describe '#call' do
    let(:builder) { described_class.new }

    context 'when :strategy key was absent in given options' do
      it 'raises an error' do
        expect { builder.call }.to raise_error(StandardError, ':strategy option must not be nil.')
      end
    end

    context 'when strategy registered under :strategy key was not found' do
      it 'raises an error' do
        expect { builder.call(strategy: :missing_strategy) }
          .to raise_error(StandardError, 'Strategy \'missing_strategy\' was not found.')
      end
    end

    context 'when strategy was found' do
      it 'builds new service object and sends #call to it' do
        expect(builder.call(strategy: :dummy_strategy)).to be_a(DummyStrategy)
      end
    end
  end
end
